<meta charset="utf-8">
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1">
<meta name="description" content="{% if page.summary %}{{ page.summary | strip_html | strip_newlines | truncate: 160 }}{% endif %}">
<meta name="keywords" content="{{page.tags}}{% if page.tags %}, {% endif %} {{page.keywords}}">
<title>{% if page.homepage == true %} {{site.homepage_title}} {% elsif page.title %}{{ page.title }}{% endif %}  | {{ site.site_title }}</title>


<link rel="stylesheet" href="{{ "css/syntax.css" | relative_url | prepend: site.url }}">
<link rel="stylesheet" href="{{ "css/font-awesome.min.css" | relative_url | prepend: site.url }}">
<link rel="stylesheet" href="{{ "css/bootstrap.min.css" | relative_url | prepend: site.url }}">
<link rel="stylesheet" href="{{ "css/modern-business.css" | relative_url | prepend: site.url }}">
<link rel="stylesheet" href="{{ "css/customstyles.css" | relative_url | prepend: site.url }}">
<link rel="stylesheet" href="{{ "css/theme-blue.css" | relative_url | prepend: site.url }}">
<link rel="stylesheet" href="{{ "css/syntax.css" | relative_url | prepend: site.url }}">
<link rel="stylesheet" href="{{ "css/printstyles.css" | relative_url }}">

<script>
    Prince.addScriptFunc("datestamp", function() {
        return "PDF last generated: {{ site.time | date: '%B %d, %Y' }}";
    });
</script>

<script>
    Prince.addScriptFunc("guideName", function() {
        return "{{site.print_title}} User Guide";
    });
</script>
