<div class="px-2">
    <a href="https://colab.research.google.com/github/{{site.repository}}/blob/{{page.branch | default: "master"}}/{{page.nb_path}}" target="_blank">
        <img class="notebook-badge-image" src="{{ "images/colab.svg" | relative_url }}" alt="Open In Colab"/>
    </a>
</div>
