<footer>
            <div class="row">
                <div class="col-lg-12 footer">
                  <p><img src="{{ "images/company_logo.png" | relative_url }}" alt="Company logo"/></p>
               &copy;{{ site.time | date: "%Y"  }} {{site.company_name}}. All rights reserved. <br />
{% if page.last_updated %}<span>Page last updated:</span> {{page.last_updated}}<br/>{% endif %} Site last generated: {{ site.time | date: "%b %-d, %Y"  }} <br />
                </div>
            </div>
</footer>
