# AUTOGENERATED! DO NOT EDIT! File to edit: 01_ts_demo.ipynb (unless otherwise specified).

__all__ = ['say_hello', 'say_hello1']

# Cell
def say_hello(to):
    "Say hello to somebody"
    return f'Hello {to}!'

# Cell
def say_hello1(to):
    "Say hello to somebody"
    return f'Hello {to}!'